==> nextcloud-app-news-16.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Užklausa nepavyko, tinklo ryšys neprieinamas!",
    "Request unauthorized. Are you logged in?" : "Užklausa neleidžiama. Ar esate prisijungę?",
    "Request forbidden. Are you an admin?" : "Užklausa draudžiama. Ar esate administratorius?",
    "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
    "Unread articles" : "Neskaityti straipsniai",
    "News" : "Naujienos",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Purge interval" : "Išvalymo intervalas",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "For more information check the wiki." : "Išsamesnei informacijai, žiūrėkite vikį.",
    "Saved" : "Įrašyta",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Subscribe to" : "Prenumeruoti",
    "No articles available" : "Nėra straipsnių",
    "No unread articles available" : "Nėra neperskaitytų straipsnių",
    "Open website" : "Atverti svetainę",
    "Star article" : "Pažymėti straipsnį žvaigždute",
    "Unstar article" : "Nebežymėti straipsnio žvaigždute",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Username" : "Naudotojo vardas",
    "by" : " ",
    "from" : "iš",
    "Play audio" : "Groti",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Description" : "Aprašas",
    "right" : "dešinė",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "left" : "kairė",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Star article and jump to next one" : "Pažymėti straipsnį ir peršokti prie kito",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Refresh" : "Įkelti iš naujo",
    "Load next feed" : "Įkelti kitą kanalą",
    "Load previous feed" : "Įkelti ankstesnį kanalą",
    "Load next folder" : "Įkelti kitą aplanką",
    "Load previous folder" : "Įkelti ankstesnį aplanką",
    "Scroll to active navigation entry" : "Slinkti į aktyvų naršymo įrašą",
    "Focus search field" : "Fokusuoti paieškos lauką",
    "Mark current article's feed/folder read" : "Žymėti esamo straipsnio kanalą/aplanką kaip skaitytą",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API",
    "Subscribe" : "Prenumeruoti",
    "Web address" : "Saityno adresas",
    "Feed exists already!" : "Kanalas jau yra!",
    "Folder" : "Aplankas",
    "No folder" : "Be aplanko",
    "New folder" : "Naujas aplankas",
    "Folder name" : "Aplanko pavadinimas",
    "Go back" : "Grįžti",
    "Folder exists already!" : "Aplankas jau yra!",
    "Credentials" : "Prisijungimo duomenys ",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Password" : "Slaptažodis",
    "New Folder" : "Naujas aplankas",
    "Create" : "Sukurti",
    "Explore" : "Išvalgyti",
    "Update failed more than 50 times" : "Atnaujinimas daugiau kaip 50 kartų patyrė nesėkmę",
    "Deleted feed" : "Ištrintas kanalas",
    "Undo delete feed" : "Atšaukti kanalo ištrynimą",
    "Rename" : "Pervadinti",
    "Menu" : "Meniu",
    "Mark read" : "Žymėti kaip skaitytą",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
    "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
    "Open feed URL" : "Atverti kanalo URL",
    "Delete" : "Ištrinti",
    "Dismiss" : "Pašalinti",
    "Collapse" : "Suskleisti",
    "Deleted folder" : "Ištrintas aplankas",
    "Undo delete folder" : "Atšaukti aplanko ištrynimą",
    "Starred" : "Pažymėti žvaigždute",
    "All articles" : "Visi straipsniai",
    "Settings" : "Nustatymai",
    "Compact view" : "Rodyti tik antraštes",
    "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
    "Show all articles" : "Rodyti visus straipsnius",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Subscriptions (OPML)" : "Prenumeratos (OPML)",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Error when importing: File does not contain valid OPML" : "Klaida importuojant: Faile nėra tinkamo OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Klaida, importuojant: OPML faile nėra nei kanalų, nei aplankų",
    "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
    "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
    "Help" : "Pagalba",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pranešti apie klaidą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-news-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/lt_LT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Užklausa nepavyko, tinklo ryšys neprieinamas!",
    "Request unauthorized. Are you logged in?" : "Užklausa neleidžiama. Ar esate prisijungę?",
    "Request forbidden. Are you an admin?" : "Užklausa draudžiama. Ar esate administratorius?",
    "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
    "Unread articles" : "Neskaityti straipsniai",
    "News" : "Naujienos",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Purge interval" : "Išvalymo intervalas",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "For more information check the wiki." : "Išsamesnei informacijai, žiūrėkite vikį.",
    "Saved" : "Įrašyta",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Subscribe to" : "Prenumeruoti",
    "No articles available" : "Nėra straipsnių",
    "No unread articles available" : "Nėra neperskaitytų straipsnių",
    "Open website" : "Atverti svetainę",
    "Star article" : "Pažymėti straipsnį žvaigždute",
    "Unstar article" : "Nebežymėti straipsnio žvaigždute",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Share" : "Bendrinti",
    "Username" : "Naudotojo vardas",
    "No users found" : "Nerasta jokių naudotojų",
    "by" : " ",
    "from" : "iš",
    "Play audio" : "Groti",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Description" : "Aprašas",
    "right" : "dešinė",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "left" : "kairė",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Star article and jump to next one" : "Pažymėti straipsnį ir peršokti prie kito",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Refresh" : "Įkelti iš naujo",
    "Load next feed" : "Įkelti kitą kanalą",
    "Load previous feed" : "Įkelti ankstesnį kanalą",
    "Load previous folder" : "Įkelti ankstesnį aplanką",
    "Load next folder" : "Įkelti kitą aplanką",
    "Scroll to active navigation entry" : "Slinkti į aktyvų naršymo įrašą",
    "Mark current article's feed/folder read" : "Žymėti esamo straipsnio kanalą/aplanką kaip skaitytą",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API",
    "Subscribe" : "Prenumeruoti",
    "Web address" : "Saityno adresas",
    "Feed exists already!" : "Kanalas jau yra!",
    "Folder" : "Aplankas",
    "No folder" : "Be aplanko",
    "New folder" : "Naujas aplankas",
    "Folder name" : "Aplanko pavadinimas",
    "Go back" : "Grįžti",
    "Folder exists already!" : "Aplankas jau yra!",
    "Credentials" : "Prisijungimo duomenys ",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Password" : "Slaptažodis",
    "New Folder" : "Naujas aplankas",
    "Create" : "Sukurti",
    "Explore" : "Išvalgyti",
    "Update failed more than 50 times" : "Atnaujinimas daugiau kaip 50 kartų patyrė nesėkmę",
    "Deleted feed" : "Ištrintas kanalas",
    "Undo delete feed" : "Atšaukti kanalo ištrynimą",
    "Rename" : "Pervadinti",
    "Menu" : "Meniu",
    "Mark read" : "Žymėti kaip skaitytą",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Enable full text" : "Įjungti raiškųjį tekstą",
    "Disable full text" : "Išjungti raiškųjį tekstą",
    "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
    "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
    "Open feed URL" : "Atverti kanalo URL",
    "Delete" : "Ištrinti",
    "Dismiss" : "Pašalinti",
    "Collapse" : "Suskleisti",
    "Deleted folder" : "Ištrintas aplankas",
    "Undo delete folder" : "Atšaukti aplanko ištrynimą",
    "Starred" : "Pažymėti žvaigždute",
    "All articles" : "Visi straipsniai",
    "Settings" : "Nustatymai",
    "Compact view" : "Rodyti tik antraštes",
    "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
    "Show all articles" : "Rodyti visus straipsnius",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Subscriptions (OPML)" : "Prenumeratos (OPML)",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Error when importing: File does not contain valid OPML" : "Klaida importuojant: Faile nėra tinkamo OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Klaida, importuojant: OPML faile nėra nei kanalų, nei aplankų",
    "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
    "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
    "Help" : "Pagalba",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pranešti apie klaidą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
